@@ -96,14 +96,14 @@ Backend::Backend(QObject *parent, const QVariantList &)
                         qApp->applicationVersion(),
                         PHONON_VERSION_STR,
                         PHONON_VLC_VERSION);
-            libvlc_set_user_agent(libvlc,
+            libvlc_set_user_agent(pvlc_libvlc,
                                   qApp->applicationName().toUtf8().constData(),
                                   userAgent.toUtf8().constData());
         } else {
             qWarning("WARNING: Setting the user agent for streaming and"
                      " PulseAudio requires you to set QCoreApplication::applicationName()");
         }
-#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(2, 1, 0, 0))
+
         PulseSupport::getInstance()->enable(true);
         const bool pulseActive = PulseSupport::getInstance()->isActive();
         PulseSupport::getInstance()->enable(false);
@@ -121,7 +121,7 @@ Backend::Backend(QObject *parent, const QVariantList &)
                 // If we failed to get a proper icon name, use the appname instead.
                 icon = qApp->applicationName().toLower();
             }
-            libvlc_set_app_id(libvlc,
+            libvlc_set_app_id(pvlc_libvlc,
                               id.toUtf8().constData(),
                               version.toUtf8().constData(),
                               icon.toUtf8().constData());
@@ -131,8 +131,6 @@ Backend::Backend(QObject *parent, const QVariantList &)
                      " QCoreApplication::applicationVersion() and"
                      " QGuiApplication::windowIcon().");
         }
-
-#endif
     } else {
 #ifdef __GNUC__
     #warning TODO - this error message is as useful as a knife at a gun fight
@@ -151,7 +149,7 @@ Backend::Backend(QObject *parent, const QVariantList &)
 
     // Initialise PulseAudio support
     PulseSupport *pulse = PulseSupport::getInstance();
-#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(2, 2, 0, 0))
+#if (LIBVLC_VERSION_INT < LIBVLC_VERSION(2, 2, 2, 0))
     // VLC 2.2 changed the stream creation order around internally which breaks
     // the Pulseaudio hijacking. Since VLC upstream doesn't feel like giving us
     // any more property control we now consider this feature unsupported. As
@@ -159,8 +157,6 @@ Backend::Backend(QObject *parent, const QVariantList &)
     pulse->enable(true);
     connect(pulse, SIGNAL(objectDescriptionChanged(ObjectDescriptionType)),
             SIGNAL(objectDescriptionChanged(ObjectDescriptionType)));
-#else
-    pulse->enable(false);
 #endif
 
     m_deviceManager = new DeviceManager(this);
@@ -180,7 +176,7 @@ Backend::~Backend()
 
 QObject *Backend::createObject(BackendInterface::Class c, QObject *parent, const QList<QVariant> &args)
 {
-    if (!LibVLC::self || !libvlc)
+    if (!LibVLC::self || !pvlc_libvlc)
         return 0;
 
     switch (c) {
