@@ -4,7 +4,7 @@
     Copyright (C) 2009 Fathi Boudra <fabo@kde.org>
     Copyright (C) 2010 Ben Cooksley <sourtooth@gmail.com>
     Copyright (C) 2009-2011 vlc-phonon AUTHORS <kde-multimedia@kde.org>
-    Copyright (C) 2010-2011 Harald Sitter <sitter@kde.org>
+    Copyright (C) 2010-2015 Harald Sitter <sitter@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -319,8 +319,11 @@ void MediaObject::setSource(const MediaSource &source)
     case MediaSource::Url:
         debug() << "MediaSource::Url:" << source.url();
         if (source.url().scheme().isEmpty()) {
-            url = "file:///";
-            if (source.url().isRelative())
+            url = "file://";
+            // QUrl considers url.scheme.isEmpty() == url.isRelative(), 
+            // so to be sure the url is not actually absolute we just
+            // check the first character
+            if (!source.url().toString().startsWith('/'))
                 url.append(QFile::encodeName(QDir::currentPath()) + '/');
         }
         url += source.url().toEncoded();
