@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2011-2012 Harald Sitter <sitter@kde.org>
+    Copyright (C) 2011-2015 Harald Sitter <sitter@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -50,7 +50,7 @@ namespace VLC {
 MediaPlayer::MediaPlayer(QObject *parent)
     : QObject(parent)
     , m_media(0)
-    , m_player(libvlc_media_player_new(libvlc))
+    , m_player(libvlc_media_player_new(pvlc_libvlc))
     , m_doingPausedPlay(false)
     , m_volume(75)
     , m_fadeAmount(1.0f)
@@ -80,6 +80,13 @@ MediaPlayer::MediaPlayer(QObject *parent)
         libvlc_MediaPlayerSnapshotTaken,
         libvlc_MediaPlayerLengthChanged,
         libvlc_MediaPlayerVout
+    #if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(2, 2, 2, 0))
+        , libvlc_MediaPlayerCorked,
+        libvlc_MediaPlayerUncorked,
+        libvlc_MediaPlayerMuted,
+        libvlc_MediaPlayerUnmuted,
+        libvlc_MediaPlayerAudioVolume
+    #endif
     };
     const int eventCount = sizeof(events) / sizeof(*events);
     for (int i = 0; i < eventCount; ++i) {
@@ -89,9 +96,7 @@ MediaPlayer::MediaPlayer(QObject *parent)
     // Deactivate video title overlay (i.e. name of the video displaying
     // at start. Since 2.1 that is handled via the API which in general is more
     // reliable than setting it via libvlc_new (or so I have been told....)
-#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(2, 1, 0, 0))
     libvlc_media_player_set_video_title_display(m_player, libvlc_position_disable, 0);
-#endif
 }
 
 MediaPlayer::~MediaPlayer()
@@ -279,6 +284,32 @@ void MediaPlayer::event_cb(const libvlc_event_t *event, void *opaque)
         break;
     case libvlc_MediaPlayerMediaChanged:
         break;
+#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(2, 2, 2, 0))
+    case libvlc_MediaPlayerCorked:
+        that->pause();
+        break;
+    case libvlc_MediaPlayerUncorked:
+        that->play();
+        break;
+    case libvlc_MediaPlayerMuted:
+        QMetaObject::invokeMethod(
+                    that, "mutedChanged",
+                    Qt::QueuedConnection,
+                    Q_ARG(bool, true));
+        break;
+    case libvlc_MediaPlayerUnmuted:
+        QMetaObject::invokeMethod(
+                    that, "mutedChanged",
+                    Qt::QueuedConnection,
+                    Q_ARG(bool, false));
+        break;
+    case libvlc_MediaPlayerAudioVolume:
+        QMetaObject::invokeMethod(
+                    that, "volumeChanged",
+                    Qt::QueuedConnection,
+                    Q_ARG(float, event->u.media_player_audio_volume.volume));
+        break;
+#endif
     case libvlc_MediaPlayerForward:
     case libvlc_MediaPlayerBackward:
     case libvlc_MediaPlayerPositionChanged:
@@ -338,6 +369,16 @@ void MediaPlayer::setAudioVolume(int volume)
     setVolumeInternal();
 }
 
+bool MediaPlayer::mute() const
+{
+    return libvlc_audio_get_mute(m_player);
+}
+
+void MediaPlayer::setMute(bool mute)
+{
+    libvlc_audio_set_mute(m_player, mute);
+}
+
 void MediaPlayer::setVolumeInternal()
 {
     libvlc_audio_set_volume(m_player, m_volume * m_fadeAmount);
